Re: Audacity 3.0.0 RC 005 for testing

"Leland" <[email protected]>
Newsgroups gmane.comp.audio.audacity.devel
Message-ID <[email protected]>
The answer is that we made the bogus assumption that wxChar == the wxString character size.  Apparently, this is not always the case and we should have used wxStringCharType instead of wxChar.  It comes down to wxWidgets on FreeBSD using UTF8 for Unicode.  If our wxWidgets were used or if we used the correct type for character size, then you would have been fine.

You can apply the attached patch, rebuild Audacity, and you should be fine.  This is what I will be committing as soon as I get the go ahead from the RM.

To be clear, the problem will only affect platforms that use the system wxWidgets when building Audacity and where the system wxWidgets is set up  to use UTF-8 as the wxWidgets internal character format.  The patch corrects our usage of wxChar when writing our project XML and does NOT introduce an incompatibility in the project file.

> -----Original Message-----
> From: Jack L. <[email protected]>
> Sent: Thursday, March 18, 2021 3:05 AM
> To: Audacity-Devel list <[email protected]>
> Subject: Re: [Audacity-devel] Audacity 3.0.0 RC 005 for testing
> 
> Ok thanks, I've attached the patch to bring the ports version on FreeBSD up to
> 3.0.0. cd /usr/ports/audio/audacity;patch -p1 -B ''
> <audacity.txt
> 
> On the windows unable to open project database issue, it looks like this is
> another open multiple audio files issue. I was able to reproduce on windows
> with 1. Ctrl+o, open audio file 2. Ctrl+o, open audio file (unable to open
> project's database sometimes) 3. Ctrl+o, open audio file (unable to open
> project's database)
> 
> Also, when that unable to open project's database comes up, the next time
> you start audacity, it will keep saying to recover a crashed project even though
> it was closed cleanly and sometimes results in the same unable to open
> project's database error until you close/open audacity a few times.
> 
> Also getting early here too, 1AM here ;)
> 
> On Thu, Mar 18, 2021 at 12:50 AM Jack L. <[email protected]> wrote:
> >
> > Had to recapture the screenshot with the dialog box in front instead
> > of behind the window
> >
> > On Thu, Mar 18, 2021 at 12:43 AM Jack L. <[email protected]> wrote:
> > >
> > > If it can't be recovered, it's fine, but it would be good to know
> > > why it saved a broken file anyways.
> > >
> > >
> > > Also on windows, if I right click on a file and click on "Open with
> > > audacity", I get a dialog that says "automated crash recovery of New
> > > Project" and then an unable to open database error. Nothing else can
> > > be imported/opened until I fully close audacity and open it again.
> > > Seems like something is broken if audacity isn't opened before the
> > > file is loaded into it.
> > >
> > > On Thu, Mar 18, 2021 at 12:31 AM Leland <[email protected]> wrote:
> > > >
> > > > I get the same error here...that's good.  Something to do with
> > > > Unicode encoding...still checking.
> > > >
> > > > > -----Original Message-----
> > > > > From: Jack L. <[email protected]>
> > > > > Sent: Thursday, March 18, 2021 1:37 AM
> > > > > To: Audacity-Devel list <[email protected]>
> > > > > Subject: Re: [Audacity-devel] Audacity 3.0.0 RC 005 for testing
> > > > >
> > > > > In case the link didn't go through https://we.tl/t-u9D0IXqGW9
> > > > > has the problem aup3 file and egrep
> > > > >
> > > > > On Wed, Mar 17, 2021 at 11:16 PM Jack L. <[email protected]>
> wrote:
> > > > > >
> > > > > > The file is sending via wetransfer, hopefully it can send to the list.
> > > > > > The dump|egrep is included in the transfer. Total is about
> > > > > > 500M bzipped
> > > > > >
> > > > > >
> > > > > > On Wed, Mar 17, 2021 at 10:51 PM Leland <[email protected]>
> wrote:
> > > > > > >
> > > > > > > Oh, oh!  Would you be able to compress it and upload to
> > > > > > > google drive or some such?  If it's too big, can you send me the
> output from:
> > > > > > >
> > > > > > > sqlite3 ee.aup3 '.dump' | egrep 'project|autosave'
> > > > > > >
> > > > > > > That will dump the project file (just a binary
> > > > > > > representation of an XML
> > > > > > > document) and it may shed some light as to what has
> > > > > > > happened.  If I can figure it out, I may be able to modify
> > > > > > > it, send it back to you, and you can replace it in the .aup3.
> > > > > > >
> > > > > > > > -----Original Message-----
> > > > > > > > From: Jack L. <[email protected]>
> > > > > > > > Sent: Thursday, March 18, 2021 12:07 AM
> > > > > > > > To: Audacity-Devel list
> > > > > > > > <[email protected]>
> > > > > > > > Subject: Re: [Audacity-devel] Audacity 3.0.0 RC 005 for
> > > > > > > > testing
> > > > > > > >
> > > > > > > > I'll have to check and get back to you.
> > > > > > > >
> > > > > > > > I just recorded a 1hr audio file on FreeBSD and saved it.
> > > > > > > > Tried to open it
> > > > > > > later
> > > > > > > > and it says "Unable to parse project information".
> > > > > > > >
> > > > > > > > file.aup3: SQLite 3.x database, application id 1096107097,
> > > > > > > > user version 50331648, last written using SQLite version
> > > > > > > > 3034001
> > > > > > > >
> > > > > > > > Same thing happens when I try to open the file on windows.
> > > > > > > > Any ideas on
> > > > > > > how
> > > > > > > > I can recover the audio?
> > > > > > > >
> > > > > > > > On Wed, Mar 17, 2021 at 8:25 PM Leland <[email protected]>
> wrote:
> > > > > > > > >
> > > > > > > > > That's weird.  It "should" detect gtk3 instead of gtk2.
> > > > > > > > > What does the cmake config spit out to the terminal?
> > > > > > > > > What does
> > > > "wx-config -
> > > > > -list"
> > > > > > > show?
> > > > > > > > >
> > > > > > > > > > -----Original Message-----
> > > > > > > > > > From: Jack L. <[email protected]>
> > > > > > > > > > Sent: Wednesday, March 17, 2021 8:21 PM
> > > > > > > > > > To: Audacity-Devel list
> > > > > > > > > > <[email protected]>
> > > > > > > > > > Subject: Re: [Audacity-devel] Audacity 3.0.0 RC 005
> > > > > > > > > > for testing
> > > > > > > > > >
> > > > > > > > > > Looks like using the patched wxwidgets didn't work
> > > > > > > > > >
> > > > > > > > > > ld-elf.so.1: Shared object "libwx_gtk2u_adv-3.1.so"
> > > > > > > > > > not found, required by "audacity"
> > > > > > > > > >
> > > > > > > > > > gtk2 support was removed in FreeBSD already.
> > > > > > > > > >
> > > > > > > > > > On Wed, Mar 17, 2021 at 6:07 PM Jack L.
> > > > > > > > > > <[email protected]>
> > > > > wrote:
> > > > > > > > > > >
> > > > > > > > > > > FreeBSD uses 3.1.4, will that be ok to use instead
> > > > > > > > > > > of the patched
> > > > > > > > > version?
> > > > > > > > > > >
> > > > > > > > > > > On Wed, Mar 17, 2021 at 6:01 PM Leland
> > > > > > > > > > > <[email protected]>
> > > > > wrote:
> > > > > > > > > > > >
> > > > > > > > > > > > The reason we made our version "mandatory" is
> > > > > > > > > > > > because we were chased our tails looking for a bug
> > > > > > > > > > > > that folks using Ubuntu were reporting for many
> > > > > > > > > > > > days only to find out it was because the system
> > > > > > > > > > > > version didn't have an upstream patch
> > > > > that ours did.
> > > > > > > > > > > > Seriously, Paul and I wasted MANY hours trying to
> > > > > > > > > > > > track it
> > > > down.
> > > > > > > > > > > >
> > > > > > > > > > > > So, if FreeBSD has a more recent checkout of
> > > > > > > > > > > > wx313, then you should be okay with our patched build.
> > > > > > > > > > > >
> > > > > > > > > > > > > -----Original Message-----
> > > > > > > > > > > > > From: Jack L. <[email protected]>
> > > > > > > > > > > > > Sent: Wednesday, March 17, 2021 7:56 PM
> > > > > > > > > > > > > To: Audacity-Devel list
> > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > > > > Subject: Re: [Audacity-devel] Audacity 3.0.0 RC
> > > > > > > > > > > > > 005 for testing
> > > > > > > > > > > > >
> > > > > > > > > > > > > Looks like =local worked but not sure how happy
> > > > > > > > > > > > > the freebsd build system
> > > > > > > > > > > > will
> > > > > > > > > > > > > take that, they likely won't have git installed
> > > > > > > > > > > > > or might have to add a dependency on git before it can
> be built.
> > > > > > > > > > > > >
> > > > > > > > > > > > > Are there any gotchas if the system wxwidgets are used?
> > > > > > > > > > > > >
> > > > > > > > > > > > > On Wed, Mar 17, 2021 at 5:47 PM Jack L.
> > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > wrote:
> > > > > > > > > > > > > >
> > > > > > > > > > > > > > Let me try (I just got it to successfully
> > > > > > > > > > > > > > compile with the system version and a lot of
> > > > > > > > > > > > > > patching), but let me try with
> > > > > > > > > > > > > > -Daudacity_use_wxwidgets=local and see what
> > > > > happens.
> > > > > > > > > > > > > >
> > > > > > > > > > > > > > On Wed, Mar 17, 2021 at 5:10 PM Leland
> > > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > wrote:
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > Jack, you can specify
> > > > > > > > > > > > > > > -Daudacity_use_wxwidgets=local when
> > > > > > > > > > > > > > > configuring cmake and that will force the build to do
> a git pull of the correct wxWidgets sources.
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > -----Original Message-----
> > > > > > > > > > > > > > > > From: Jack L. <[email protected]>
> > > > > > > > > > > > > > > > Sent: Wednesday, March 17, 2021 5:29 PM
> > > > > > > > > > > > > > > > To: Audacity-Devel list
> > > > > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > > > > > > > Subject: Re: [Audacity-devel] Audacity
> > > > > > > > > > > > > > > > 3.0.0 RC
> > > > > > > > > > > > > > > > 005 for testing
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > audacity-Audacity-3.0.0/lib-src/libnyquist
> > > > > > > > > > > > > > > > /nyquist
> > > > > > > > > > > > > > > > /xlisp
> > > > > > > > > > > > > > > > /xlf
> > > > > > > > > > > > > > > > io.c
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > Line 23
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > #error configuration error -- either
> > > > > > > > > > > > > > > > XL_BIG_ or XL_LITTLE_ENDIAN must be
> > > > > > > > > > > > > > > > defined in xlisp.h
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > the "in xlisp.h" is uncommented and
> > > > > > > > > > > > > > > > causing a compilation
> > > > > > > > > error.
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > And I've noticed this hard requirement for
> > > > > > > > > > > > > > > > wxwidgets, is there a way to
> > > > > > > > > > > > > > > get it
> > > > > > > > > > > > > > > > bundled within the tar so the automated
> > > > > > > > > > > > > > > > build system can compile it
> > > > > > > > > > > > > > > without
> > > > > > > > > > > > > > > > manual intervention?
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> ################################################################
> > > > > #
> > > > > > > > > > > > > > > > #######
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >   Audacity version 3.0.0 or higher
> > > > > > > > > > > > > > > > requires use of a customized
> > > > > > > > > > > > version of
> > > > > > > > > > > > > > > >   wxWidgets.  For details:
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > https://wiki.audacityteam.org/wiki/Buildin
> > > > > > > > > > > > > > > > g_for_Di
> > > > > > > > > > > > > > > > stros
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> ################################################################
> > > > > #
> > > > > > > > > > > > > > > > #######
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > On Sun, Mar 7, 2021 at 4:25 AM James Crook
> > > > > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > > > > > > > wrote:
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > I'm hoping this one is going to be the
> > > > > > > > > > > > > > > > > actual
> > > > release.
> > > > > > > > > > > > > > > > > It's up on FossHub
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > https://www.fosshub.com/Audacity-devel.h
> > > > > > > > > > > > > > > > > tml
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > Compressor is fixed and many links in
> > > > > > > > > > > > > > > > > the manual
> > > > fixed.
> > > > > > > > > > > > > > > > > If all goes
> > > > > > > > > > > > > > > well,
> > > > > > > > > > > > > > > > releasing March 21st.
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > --James.
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-win-3.0.0rc05.exe
> > > > > > > > > > > > > > > > > (application/x-msdownload)
> > > > > > > > > > > > > > > > > -
> > > > > > > > > > > > > > > > > 29379816 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> d767acfa3ea92b23cfa8b419e9a0ecb0adecaa9478f981427985faee580271e7
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-macos-3.0.0rc05.dmg (n/a) -
> > > > > > > > > > > > > > > > > 41326838 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> 4d2d6d695aa1ea9bb25b5083c31fa57fc5bc53750977a218f2d0a3ad6f88518b
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-minsrc-3.0.0rc05.tar.xz (n/a) -
> > > > > > > > > > > > > > > > > 13308608 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> d57a6619f857c07de873d4f53389ae57b480901c2faa4f79801985f9f1daa2f1
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-manual-3.0.0rc05.zip
> > > > > > > > > > > > > > > > > (application/x-zip-compressed) -
> > > > > > > > > > > > > > > > > 23102002 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> 77d6a2bf4155568d0983608d0a232f404c64f0d200303a46ee158cf8ff79a764
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-win-3.0.0rc05.zip
> > > > > > > > > > > > > > > > > (application/x-zip-compressed)
> > > > > > > > > > > > > > > > > -
> > > > > > > > > > > > > > > > > 12507490 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> f7681aa47b1fe51aac8a21e3c81df7399f089c74eed5066dd3073edbf5f2cb06
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > ________________________________________
> > > > > > > > > > > > > > > > > _______ audacity-devel mailing list
> > > > > > > > > > > > > > > > > [email protected]
> > > > > > > > > > > > > > > > > https://lists.sourceforge.net/lists/list
> > > > > > > > > > > > > > > > > info/aud
> > > > > > > > > > > > > > > > > acity-
> > > > > > > > > > > > > > > > > deve
> > > > > > > > > > > > > > > > > l
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > __________________________________________
> > > > > > > > > > > > > > > > _____ audacity-devel mailing list
> > > > > > > > > > > > > > > > [email protected]
> > > > > > > > > > > > > > > > https://lists.sourceforge.net/lists/listin
> > > > > > > > > > > > > > > > fo/audac
> > > > > > > > > > > > > > > > ity-de
> > > > > > > > > > > > > > > > vel
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > ____________________________________________
> > > > > > > > > > > > > > > ___ audacity-devel mailing list
> > > > > > > > > > > > > > > [email protected]
> > > > > > > > > > > > > > > https://lists.sourceforge.net/lists/listinfo
> > > > > > > > > > > > > > > /audacit
> > > > > > > > > > > > > > > y-deve
> > > > > > > > > > > > > > > l
> > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > > > > > _______________________________________________
> > > > > > > > > > > > > audacity-devel mailing list
> > > > > > > > > > > > > [email protected]
> > > > > > > > > > > > > https://lists.sourceforge.net/lists/listinfo/aud
> > > > > > > > > > > > > acity-de
> > > > > > > > > > > > > vel
> > > > > > > > > > > >
> > > > > > > > > > > >
> > > > > > > > > > > >
> > > > > > > > > > > > _______________________________________________
> > > > > > > > > > > > audacity-devel mailing list
> > > > > > > > > > > > [email protected]
> > > > > > > > > > > > https://lists.sourceforge.net/lists/listinfo/audac
> > > > > > > > > > > > ity-deve
> > > > > > > > > > > > l
> > > > > > > > > >
> > > > > > > > > >
> > > > > > > > > > _______________________________________________
> > > > > > > > > > audacity-devel mailing list
> > > > > > > > > > [email protected]
> > > > > > > > > > https://lists.sourceforge.net/lists/listinfo/audacity-
> > > > > > > > > > devel
> > > > > > > > >
> > > > > > > > >
> > > > > > > > >
> > > > > > > > > _______________________________________________
> > > > > > > > > audacity-devel mailing list
> > > > > > > > > [email protected]
> > > > > > > > > https://lists.sourceforge.net/lists/listinfo/audacity-de
> > > > > > > > > vel
> > > > > > > >
> > > > > > > >
> > > > > > > > _______________________________________________
> > > > > > > > audacity-devel mailing list
> > > > > > > > [email protected]
> > > > > > > > https://lists.sourceforge.net/lists/listinfo/audacity-deve
> > > > > > > > l
> > > > > > >
> > > > > > >
> > > > > > >
> > > > > > > _______________________________________________
> > > > > > > audacity-devel mailing list
> > > > > > > [email protected]
> > > > > > > https://lists.sourceforge.net/lists/listinfo/audacity-devel
> > > > >
> > > > >
> > > > > _______________________________________________
> > > > > audacity-devel mailing list
> > > > > [email protected]
> > > > > https://lists.sourceforge.net/lists/listinfo/audacity-devel
> > > >
> > > >
> > > >
> > > > _______________________________________________
> > > > audacity-devel mailing list
> > > > [email protected]
> > > > https://lists.sourceforge.net/lists/listinfo/audacity-devel
> On Thu, Mar 18, 2021 at 12:59 AM Leland <[email protected]> wrote:
> >
> > It's coming back to you now.
> >
> > As part of the save process, we write the size of wxChar to the database.  On
> your system, that seems to be reporting 4 bytes per character, but the actual
> data is 1 byte per character.  So I was able to recover it by simply overriding
> the wxChar size stored in the database with 1 and it loaded just fine.  I will try
> to diagnose why in the morning (3am here right now).  I "may" be asking you
> for your patches so I can build it on my FreeBSD system here.
> >
> > > -----Original Message-----
> > > From: Jack L. <[email protected]>
> > > Sent: Thursday, March 18, 2021 2:44 AM
> > > To: Audacity-Devel list <[email protected]>
> > > Subject: Re: [Audacity-devel] Audacity 3.0.0 RC 005 for testing
> > >
> > > If it can't be recovered, it's fine, but it would be good to know
> > > why it saved a broken file anyways.
> > >
> > >
> > > Also on windows, if I right click on a file and click on "Open with
> > > audacity", I get a dialog that says "automated crash recovery of New
> > > Project" and then an unable to open database error. Nothing else can
> > > be imported/opened until I fully close audacity and open it again.
> > > Seems like something is broken if audacity isn't opened before the
> > > file is loaded into it.
> > >
> > > On Thu, Mar 18, 2021 at 12:31 AM Leland <[email protected]> wrote:
> > > >
> > > > I get the same error here...that's good.  Something to do with
> > > > Unicode encoding...still checking.
> > > >
> > > > > -----Original Message-----
> > > > > From: Jack L. <[email protected]>
> > > > > Sent: Thursday, March 18, 2021 1:37 AM
> > > > > To: Audacity-Devel list <[email protected]>
> > > > > Subject: Re: [Audacity-devel] Audacity 3.0.0 RC 005 for testing
> > > > >
> > > > > In case the link didn't go through https://we.tl/t-u9D0IXqGW9
> > > > > has the problem aup3 file and egrep
> > > > >
> > > > > On Wed, Mar 17, 2021 at 11:16 PM Jack L. <[email protected]>
> > > wrote:
> > > > > >
> > > > > > The file is sending via wetransfer, hopefully it can send to the list.
> > > > > > The dump|egrep is included in the transfer. Total is about
> > > > > > 500M bzipped
> > > > > >
> > > > > >
> > > > > > On Wed, Mar 17, 2021 at 10:51 PM Leland <[email protected]>
> > > wrote:
> > > > > > >
> > > > > > > Oh, oh!  Would you be able to compress it and upload to
> > > > > > > google drive or some such?  If it's too big, can you send me the
> output from:
> > > > > > >
> > > > > > > sqlite3 ee.aup3 '.dump' | egrep 'project|autosave'
> > > > > > >
> > > > > > > That will dump the project file (just a binary
> > > > > > > representation of an XML
> > > > > > > document) and it may shed some light as to what has happened.
> > > > > > > If I can figure it out, I may be able to modify it, send it
> > > > > > > back to you, and you can replace it in the .aup3.
> > > > > > >
> > > > > > > > -----Original Message-----
> > > > > > > > From: Jack L. <[email protected]>
> > > > > > > > Sent: Thursday, March 18, 2021 12:07 AM
> > > > > > > > To: Audacity-Devel list
> > > > > > > > <[email protected]>
> > > > > > > > Subject: Re: [Audacity-devel] Audacity 3.0.0 RC 005 for
> > > > > > > > testing
> > > > > > > >
> > > > > > > > I'll have to check and get back to you.
> > > > > > > >
> > > > > > > > I just recorded a 1hr audio file on FreeBSD and saved it.
> > > > > > > > Tried to open it
> > > > > > > later
> > > > > > > > and it says "Unable to parse project information".
> > > > > > > >
> > > > > > > > file.aup3: SQLite 3.x database, application id 1096107097,
> > > > > > > > user version 50331648, last written using SQLite version
> > > > > > > > 3034001
> > > > > > > >
> > > > > > > > Same thing happens when I try to open the file on windows.
> > > > > > > > Any ideas on
> > > > > > > how
> > > > > > > > I can recover the audio?
> > > > > > > >
> > > > > > > > On Wed, Mar 17, 2021 at 8:25 PM Leland
> > > > > > > > <[email protected]>
> > > wrote:
> > > > > > > > >
> > > > > > > > > That's weird.  It "should" detect gtk3 instead of gtk2.
> > > > > > > > > What does the cmake config spit out to the terminal?
> > > > > > > > > What does
> > > > "wx-config -
> > > > > -list"
> > > > > > > show?
> > > > > > > > >
> > > > > > > > > > -----Original Message-----
> > > > > > > > > > From: Jack L. <[email protected]>
> > > > > > > > > > Sent: Wednesday, March 17, 2021 8:21 PM
> > > > > > > > > > To: Audacity-Devel list
> > > > > > > > > > <[email protected]>
> > > > > > > > > > Subject: Re: [Audacity-devel] Audacity 3.0.0 RC 005
> > > > > > > > > > for testing
> > > > > > > > > >
> > > > > > > > > > Looks like using the patched wxwidgets didn't work
> > > > > > > > > >
> > > > > > > > > > ld-elf.so.1: Shared object "libwx_gtk2u_adv-3.1.so"
> > > > > > > > > > not found, required by "audacity"
> > > > > > > > > >
> > > > > > > > > > gtk2 support was removed in FreeBSD already.
> > > > > > > > > >
> > > > > > > > > > On Wed, Mar 17, 2021 at 6:07 PM Jack L.
> > > > > > > > > > <[email protected]>
> > > > > wrote:
> > > > > > > > > > >
> > > > > > > > > > > FreeBSD uses 3.1.4, will that be ok to use instead
> > > > > > > > > > > of the patched
> > > > > > > > > version?
> > > > > > > > > > >
> > > > > > > > > > > On Wed, Mar 17, 2021 at 6:01 PM Leland
> > > > > > > > > > > <[email protected]>
> > > > > wrote:
> > > > > > > > > > > >
> > > > > > > > > > > > The reason we made our version "mandatory" is
> > > > > > > > > > > > because we were chased our tails looking for a bug
> > > > > > > > > > > > that folks using Ubuntu were reporting for many
> > > > > > > > > > > > days only to find out it was because the system
> > > > > > > > > > > > version didn't have an upstream patch
> > > > > that ours did.
> > > > > > > > > > > > Seriously, Paul and I wasted MANY hours trying to
> > > > > > > > > > > > track it
> > > > down.
> > > > > > > > > > > >
> > > > > > > > > > > > So, if FreeBSD has a more recent checkout of
> > > > > > > > > > > > wx313, then you should be okay with our patched build.
> > > > > > > > > > > >
> > > > > > > > > > > > > -----Original Message-----
> > > > > > > > > > > > > From: Jack L. <[email protected]>
> > > > > > > > > > > > > Sent: Wednesday, March 17, 2021 7:56 PM
> > > > > > > > > > > > > To: Audacity-Devel list
> > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > > > > Subject: Re: [Audacity-devel] Audacity 3.0.0 RC
> > > > > > > > > > > > > 005 for testing
> > > > > > > > > > > > >
> > > > > > > > > > > > > Looks like =local worked but not sure how happy
> > > > > > > > > > > > > the freebsd build system
> > > > > > > > > > > > will
> > > > > > > > > > > > > take that, they likely won't have git installed
> > > > > > > > > > > > > or might have to add a dependency on git before it can
> be built.
> > > > > > > > > > > > >
> > > > > > > > > > > > > Are there any gotchas if the system wxwidgets are used?
> > > > > > > > > > > > >
> > > > > > > > > > > > > On Wed, Mar 17, 2021 at 5:47 PM Jack L.
> > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > wrote:
> > > > > > > > > > > > > >
> > > > > > > > > > > > > > Let me try (I just got it to successfully
> > > > > > > > > > > > > > compile with the system version and a lot of
> > > > > > > > > > > > > > patching), but let me try with
> > > > > > > > > > > > > > -Daudacity_use_wxwidgets=local and see what
> > > > > happens.
> > > > > > > > > > > > > >
> > > > > > > > > > > > > > On Wed, Mar 17, 2021 at 5:10 PM Leland
> > > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > wrote:
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > Jack, you can specify
> > > > > > > > > > > > > > > -Daudacity_use_wxwidgets=local when
> > > > > > > > > > > > > > > configuring cmake and that will force the
> > > > > > > > > > > > > > > build to do a git pull of the
> > > correct wxWidgets sources.
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > -----Original Message-----
> > > > > > > > > > > > > > > > From: Jack L. <[email protected]>
> > > > > > > > > > > > > > > > Sent: Wednesday, March 17, 2021 5:29 PM
> > > > > > > > > > > > > > > > To: Audacity-Devel list
> > > > > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > > > > > > > Subject: Re: [Audacity-devel] Audacity
> > > > > > > > > > > > > > > > 3.0.0 RC
> > > > > > > > > > > > > > > > 005 for testing
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > audacity-Audacity-3.0.0/lib-src/libnyquist
> > > > > > > > > > > > > > > > /nyq
> > > > > > > > > > > > > > > > uist
> > > > > > > > > > > > > > > > /xlisp
> > > > > > > > > > > > > > > > /xlf
> > > > > > > > > > > > > > > > io.c
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > Line 23
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > #error configuration error -- either
> > > > > > > > > > > > > > > > XL_BIG_ or XL_LITTLE_ENDIAN must be
> > > > > > > > > > > > > > > > defined in xlisp.h
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > the "in xlisp.h" is uncommented and
> > > > > > > > > > > > > > > > causing a compilation
> > > > > > > > > error.
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > And I've noticed this hard requirement for
> > > > > > > > > > > > > > > > wxwidgets, is there a way to
> > > > > > > > > > > > > > > get it
> > > > > > > > > > > > > > > > bundled within the tar so the automated
> > > > > > > > > > > > > > > > build system can compile it
> > > > > > > > > > > > > > > without
> > > > > > > > > > > > > > > > manual intervention?
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> > >
> #################################################################
> > > > > > > > > > > > > > > > #######
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >   Audacity version 3.0.0 or higher
> > > > > > > > > > > > > > > > requires use of a customized
> > > > > > > > > > > > version of
> > > > > > > > > > > > > > > >   wxWidgets.  For details:
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > https://wiki.audacityteam.org/wiki/Buildin
> > > > > > > > > > > > > > > > g_fo
> > > > > > > > > > > > > > > > r_Di
> > > > > > > > > > > > > > > > stros
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> > >
> #################################################################
> > > > > > > > > > > > > > > > #######
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > On Sun, Mar 7, 2021 at 4:25 AM James Crook
> > > > > > > > > > > > > > > > <[email protected]>
> > > > > > > > > > > > > > > > wrote:
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > I'm hoping this one is going to be the
> > > > > > > > > > > > > > > > > actual
> > > > release.
> > > > > > > > > > > > > > > > > It's up on FossHub
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > https://www.fosshub.com/Audacity-devel.h
> > > > > > > > > > > > > > > > > tml
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > Compressor is fixed and many links in
> > > > > > > > > > > > > > > > > the manual
> > > > fixed.
> > > > > > > > > > > > > > > > > If all goes
> > > > > > > > > > > > > > > well,
> > > > > > > > > > > > > > > > releasing March 21st.
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > --James.
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-win-3.0.0rc05.exe
> > > > > > > > > > > > > > > > > (application/x-msdownload)
> > > > > > > > > > > > > > > > > -
> > > > > > > > > > > > > > > > > 29379816 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> > >
> d767acfa3ea92b23cfa8b419e9a0ecb0adecaa9478f981427985faee580271e7
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-macos-3.0.0rc05.dmg (n/a) -
> > > > > > > > > > > > > > > > > 41326838 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> > >
> 4d2d6d695aa1ea9bb25b5083c31fa57fc5bc53750977a218f2d0a3ad6f88518b
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-minsrc-3.0.0rc05.tar.xz (n/a) -
> > > > > > > > > > > > > > > > > 13308608 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> > >
> d57a6619f857c07de873d4f53389ae57b480901c2faa4f79801985f9f1daa2f1
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-manual-3.0.0rc05.zip
> > > > > > > > > > > > > > > > > (application/x-zip-compressed) -
> > > > > > > > > > > > > > > > > 23102002 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> > >
> 77d6a2bf4155568d0983608d0a232f404c64f0d200303a46ee158cf8ff79a764
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > audacity-win-3.0.0rc05.zip
> > > > > > > > > > > > > > > > > (application/x-zip-compressed)
> > > > > > > > > > > > > > > > > -
> > > > > > > > > > > > > > > > > 12507490 bytes
> > > > > > > > > > > > > > > > > SHA-256
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > >
> > > > > > > >
> > > > >
> > >
> f7681aa47b1fe51aac8a21e3c81df7399f089c74eed5066dd3073edbf5f2cb06
> > > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > > ________________________________________
> > > > > > > > > > > > > > > > > ____ ___ audacity-devel mailing list
> > > > > > > > > > > > > > > > > [email protected]
> > > > > > > > > > > > > > > > > https://lists.sourceforge.net/lists/list
> > > > > > > > > > > > > > > > > info
> > > > > > > > > > > > > > > > > /aud
> > > > > > > > > > > > > > > > > acity-
> > > > > > > > > > > > > > > > > deve
> > > > > > > > > > > > > > > > > l
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > > __________________________________________
> > > > > > > > > > > > > > > > ____ _ audacity-devel mailing list
> > > > > > > > > > > > > > > > [email protected]
> > > > > > > > > > > > > > > > https://lists.sourceforge.net/lists/listin
> > > > > > > > > > > > > > > > fo/a
> > > > > > > > > > > > > > > > udac
> > > > > > > > > > > > > > > > ity-de
> > > > > > > > > > > > > > > > vel
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > >
> > > > > > > > > > > > > > > ____________________________________________
> > > > > > > > > > > > > > > ___ audacity-devel mailing list
> > > > > > > > > > > > > > > [email protected]
> > > > > > > > > > > > > > > https://lists.sourceforge.net/lists/listinfo
> > > > > > > > > > > > > > > /aud
> > > > > > > > > > > > > > > acit
> > > > > > > > > > > > > > > y-deve
> > > > > > > > > > > > > > > l
> > > > > > > > > > > > >
> > > > > > > > > > > > >
> > > > > > > > > > > > > _______________________________________________
> > > > > > > > > > > > > audacity-devel mailing list
> > > > > > > > > > > > > [email protected]
> > > > > > > > > > > > > https://lists.sourceforge.net/lists/listinfo/aud
> > > > > > > > > > > > > acit
> > > > > > > > > > > > > y-de
> > > > > > > > > > > > > vel
> > > > > > > > > > > >
> > > > > > > > > > > >
> > > > > > > > > > > >
> > > > > > > > > > > > _______________________________________________
> > > > > > > > > > > > audacity-devel mailing list
> > > > > > > > > > > > [email protected]
> > > > > > > > > > > > https://lists.sourceforge.net/lists/listinfo/audac
> > > > > > > > > > > > ity-
> > > > > > > > > > > > deve
> > > > > > > > > > > > l
> > > > > > > > > >
> > > > > > > > > >
> > > > > > > > > > _______________________________________________
> > > > > > > > > > audacity-devel mailing list
> > > > > > > > > > [email protected]
> > > > > > > > > > https://lists.sourceforge.net/lists/listinfo/audacity-
> > > > > > > > > > deve
> > > > > > > > > > l
> > > > > > > > >
> > > > > > > > >
> > > > > > > > >
> > > > > > > > > _______________________________________________
> > > > > > > > > audacity-devel mailing list
> > > > > > > > > [email protected]
> > > > > > > > > https://lists.sourceforge.net/lists/listinfo/audacity-de
> > > > > > > > > vel
> > > > > > > >
> > > > > > > >
> > > > > > > > _______________________________________________
> > > > > > > > audacity-devel mailing list
> > > > > > > > [email protected]
> > > > > > > > https://lists.sourceforge.net/lists/listinfo/audacity-deve
> > > > > > > > l
> > > > > > >
> > > > > > >
> > > > > > >
> > > > > > > _______________________________________________
> > > > > > > audacity-devel mailing list
> > > > > > > [email protected]
> > > > > > > https://lists.sourceforge.net/lists/listinfo/audacity-devel
> > > > >
> > > > >
> > > > > _______________________________________________
> > > > > audacity-devel mailing list
> > > > > [email protected]
> > > > > https://lists.sourceforge.net/lists/listinfo/audacity-devel
> > > >
> > > >
> > > >
> > > > _______________________________________________
> > > > audacity-devel mailing list
> > > > [email protected]
> > > > https://lists.sourceforge.net/lists/listinfo/audacity-devel
> >
> >
> >
> > _______________________________________________
> > audacity-devel mailing list
> > [email protected]
> > https://lists.sourceforge.net/lists/listinfo/audacity-devel

_______________________________________________
audacity-devel mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/audacity-devel
wxchar_patch.diff (application/octet-stream, 2.5 KB)
diff --git a/src/ProjectSerializer.cpp b/src/ProjectSerializer.cpp
index 4fe44a7fd..e1d413d3f 100644
--- a/src/ProjectSerializer.cpp
+++ b/src/ProjectSerializer.cpp
@@ -206,9 +206,9 @@ ProjectSerializer::ProjectSerializer(size_t allocSize)
    std::call_once(flag, []{
       // Just once per run, store header information in the unique static
       // dictionary that will be written into each project that is saved.
-      // Store the size of "wxChar" so we can convert during recovery in
-      // case the file is used on a system with a different character size.
-      char size = sizeof(wxChar);
+      // Store the size of "wxStringCharType" so we can convert during recovery
+      // in case the file is used on a system with a different character size.
+      char size = sizeof(wxStringCharType);
       mDict.AppendByte(FT_CharSize);
       mDict.AppendData(&size, 1);
    });
@@ -242,7 +242,7 @@ void ProjectSerializer::WriteAttr(const wxString & name, const wxString & value)
    mBuffer.AppendByte(FT_String);
    WriteName(name);
 
-   const Length len = value.length() * sizeof(wxChar);
+   const Length len = value.length() * sizeof(wxStringCharType);
    WriteLength( mBuffer, len );
    mBuffer.AppendData(value.wx_str(), len);
 }
@@ -309,7 +309,7 @@ void ProjectSerializer::WriteData(const wxString & value)
 {
    mBuffer.AppendByte(FT_Data);
 
-   Length len = value.length() * sizeof(wxChar);
+   Length len = value.length() * sizeof(wxStringCharType);
    WriteLength( mBuffer, len );
    mBuffer.AppendData(value.wx_str(), len);
 }
@@ -317,7 +317,7 @@ void ProjectSerializer::WriteData(const wxString & value)
 void ProjectSerializer::Write(const wxString & value)
 {
    mBuffer.AppendByte(FT_Raw);
-   Length len = value.length() * sizeof(wxChar);
+   Length len = value.length() * sizeof(wxStringCharType);
    WriteLength( mBuffer, len );
    mBuffer.AppendData(value.wx_str(), len);
 }
@@ -334,7 +334,7 @@ void ProjectSerializer::WriteSubTree(const ProjectSerializer & value)
 
 void ProjectSerializer::WriteName(const wxString & name)
 {
-   wxASSERT(name.length() * sizeof(wxChar) <= SHRT_MAX);
+   wxASSERT(name.length() * sizeof(wxStringCharType) <= SHRT_MAX);
    UShort id;
 
    auto nameiter = mNames.find(name);
@@ -346,7 +346,7 @@ void ProjectSerializer::WriteName(const wxString & name)
    {
       // mNames is static.  This appends each name to static mDict only once
       // in each run.
-      UShort len = name.length() * sizeof(wxChar);
+      UShort len = name.length() * sizeof(wxStringCharType);
 
       id = mNames.size();
       mNames[name] = id;
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.